"use strict";
exports.__esModule = true;
var htmltree = require("htmltree");
var chai_1 = require("chai");
var mocha_1 = require("mocha");
var prettyjson_pipe_1 = require("../src/prettyjson.pipe");
mocha_1.describe('Safety', function () {
    mocha_1.it('should not throw when using safe json pipe on circular structure', function () {
        var o = {};
        o.a = o;
        var pipe = new prettyjson_pipe_1.PrettyJsonPipe();
        var outcome = '';
        var fn = function () {
            outcome = pipe.transform(o);
        };
        chai_1.expect(fn).not.to["throw"](TypeError);
        // Should contain the keyword 'Circular'
        fn();
        chai_1.expect(outcome).to.contain('Circular');
    });
});
mocha_1.describe('Generated markup', function () {
    mocha_1.it('should include spans with correct classes', function (done) {
        var o = {
            num: 42,
            othernum: 5,
            somestring: 'lalala',
            somearray: [55, 'hello'],
            someobject: {
                someobject: {
                    enough: null
                }
            }
        };
        // Expected markup
        // {
        //   <span class="key">"num":</span> <span class="number">42</span>,
        //   <span class="key">"othernum":</span> <span class="number">5</span>,
        //   <span class="key">"somestring":</span> <span class="string">"lalala"</span>,
        //   <span class="key">"somearray":</span> [
        //     <span class="number">55</span>,
        //     <span class="string">"hello"</span>
        //   ],
        //   <span class="key">"someobject":</span> {
        //     <span class="key">"someobject":</span> {
        //       <span class="key">"enough":</span> <span class="null">null</span>
        //     }
        //   }
        // }
        var pipe = new prettyjson_pipe_1.PrettyJsonPipe();
        var outcome = pipe.transform(o);
        // Parse html
        htmltree(outcome, function (err, htmlDoc) {
            var spans = htmlDoc.root.filter(function (element) { return element.type === 'tag'; });
            [0, 2, 4, 6, 9, 10, 11].forEach(function (index) {
                return chai_1.expect(spans[index].attributes["class"]).to.equal('key');
            });
            [1, 3, 7].forEach(function (index) {
                return chai_1.expect(spans[index].attributes["class"]).to.equal('number');
            });
            [5, 8].forEach(function (index) {
                return chai_1.expect(spans[index].attributes["class"]).to.equal('string');
            });
            chai_1.expect(spans[12].attributes["class"]).to.equal('null');
            done();
        });
    });
});
